@@ -1,6 +1,6 @@
-/* the Music Player Daemon (MPD)
- * Copyright (C) 2003-2007 by Warren Dukes (warren.dukes@gmail.com)
- * This project's homepage is: http://www.musicpd.org
+/*
+ * Copyright (C) 2003-2009 The Music Player Daemon Project
+ * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -11,20 +11,17 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "buffer2array.h"
-#include "os_compat.h"
 
-static inline
-int
-isWhiteSpace(char c)
-{
-	return (c == ' ' || c == '\t');
-}
+#include <glib.h>
+
+#include <string.h>
 
 int buffer2array(char *buffer, char *array[], const int max)
 {
@@ -44,19 +41,20 @@ int buffer2array(char *buffer, char *array[], const int max)
 				}
 			}
 		} else {
-			while (isWhiteSpace(*c))
-				++c;
-			array[i++] = c++;
+			c = g_strchug(c);
 			if (*c == '\0')
 				return i;
-			while (!isWhiteSpace(*c) && *c != '\0')
+
+			array[i++] = c++;
+
+			while (!g_ascii_isspace(*c) && *c != '\0')
 				++c;
 		}
 		if (*c == '\0')
 			return i;
 		*(c++) = '\0';
-		while (isWhiteSpace(*c))
-			++c;
+
+		c = g_strchug(c);
 	}
 	return i;
 }
