@@ -1,6 +1,6 @@
-/* the Music Player Daemon (MPD)
- * Copyright (C) 2003-2007 by Warren Dukes (warren.dukes@gmail.com)
- * This project's homepage is: http://www.musicpd.org
+/*
+ * Copyright (C) 2003-2009 The Music Player Daemon Project
+ * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -11,61 +11,47 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "dbUtils.h"
-
+#include "locate.h"
 #include "directory.h"
 #include "database.h"
 #include "client.h"
-#include "utils.h"
 #include "playlist.h"
 #include "song.h"
 #include "song_print.h"
 #include "tag.h"
 #include "strset.h"
-#include "log.h"
 #include "stored_playlist.h"
 
 #include <glib.h>
 
+#include <stdlib.h>
+
 typedef struct _ListCommandItem {
 	int8_t tagType;
-	int numConditionals;
-	LocateTagItem *conditionals;
+	const struct locate_item_list *criteria;
 } ListCommandItem;
 
-typedef struct _LocateTagItemArray {
-	int numItems;
-	LocateTagItem *items;
-} LocateTagItemArray;
-
 typedef struct _SearchStats {
-	LocateTagItemArray locateArray;
+	const struct locate_item_list *criteria;
 	int numberOfSongs;
 	unsigned long playTime;
 } SearchStats;
 
-static int
-countSongsInDirectory(struct directory *directory, void *data)
-{
-	int *count = (int *)data;
-
-	*count += directory->songs.nr;
-
-	return 0;
-}
-
 static int
 printDirectoryInDirectory(struct directory *directory, void *data)
 {
 	struct client *client = data;
-	if (!isRootDirectory(directory->path)) {
+
+	if (!directory_is_root(directory))
 		client_printf(client, "directory: %s\n", directory_get_path(directory));
-	}
+
 	return 0;
 }
 
@@ -79,47 +65,35 @@ printSongInDirectory(struct song *song, G_GNUC_UNUSED void *data)
 
 struct search_data {
 	struct client *client;
-	LocateTagItemArray array;
+	const struct locate_item_list *criteria;
 };
 
 static int
 searchInDirectory(struct song *song, void *_data)
 {
 	struct search_data *data = _data;
-	LocateTagItemArray *array = &data->array;
 
-	if (strstrSearchTags(song, array->numItems, array->items))
+	if (locate_song_search(song, data->criteria))
 		return song_print_info(data->client, song);
 
 	return 0;
 }
 
-int searchForSongsIn(struct client *client, const char *name,
-		     int numItems, LocateTagItem * items)
+int
+searchForSongsIn(struct client *client, const char *name,
+		 const struct locate_item_list *criteria)
 {
 	int ret;
-	int i;
-
-	char **originalNeedles = xmalloc(numItems * sizeof(char *));
+	struct locate_item_list *new_list
+		= locate_item_list_casefold(criteria);
 	struct search_data data;
 
-	for (i = 0; i < numItems; i++) {
-		originalNeedles[i] = items[i].needle;
-		items[i].needle = g_utf8_casefold(originalNeedles[i], -1);
-	}
-
 	data.client = client;
-	data.array.numItems = numItems;
-	data.array.items = items;
+	data.criteria = new_list;
 
 	ret = db_walk(name, searchInDirectory, NULL, &data);
 
-	for (i = 0; i < numItems; i++) {
-		g_free(items[i].needle);
-		items[i].needle = originalNeedles[i];
-	}
-
-	free(originalNeedles);
+	locate_item_list_free(new_list);
 
 	return ret;
 }
@@ -128,22 +102,21 @@ static int
 findInDirectory(struct song *song, void *_data)
 {
 	struct search_data *data = _data;
-	LocateTagItemArray *array = &data->array;
 
-	if (tagItemsFoundAndMatches(song, array->numItems, array->items))
+	if (locate_song_match(song, data->criteria))
 		return song_print_info(data->client, song);
 
 	return 0;
 }
 
-int findSongsIn(struct client *client, const char *name,
-		int numItems, LocateTagItem * items)
+int
+findSongsIn(struct client *client, const char *name,
+	    const struct locate_item_list *criteria)
 {
 	struct search_data data;
 
 	data.client = client;
-	data.array.numItems = numItems;
-	data.array.items = items;
+	data.criteria = criteria;
 
 	return db_walk(name, findInDirectory, NULL, &data);
 }
@@ -159,8 +132,7 @@ searchStatsInDirectory(struct song *song, void *data)
 {
 	SearchStats *stats = data;
 
-	if (tagItemsFoundAndMatches(song, stats->locateArray.numItems,
-	                                  stats->locateArray.items)) {
+	if (locate_song_match(song, stats->criteria)) {
 		stats->numberOfSongs++;
 		if (song->tag->time > 0)
 			stats->playTime += song->tag->time;
@@ -169,14 +141,14 @@ searchStatsInDirectory(struct song *song, void *data)
 	return 0;
 }
 
-int searchStatsForSongsIn(struct client *client, const char *name,
-			  int numItems, LocateTagItem * items)
+int
+searchStatsForSongsIn(struct client *client, const char *name,
+		      const struct locate_item_list *criteria)
 {
 	SearchStats stats;
 	int ret;
 
-	stats.locateArray.numItems = numItems;
-	stats.locateArray.items = items;
+	stats.criteria = criteria;
 	stats.numberOfSongs = 0;
 	stats.playTime = 0;
 
@@ -196,7 +168,7 @@ int printAllIn(struct client *client, const char *name)
 static int
 directoryAddSongToPlaylist(struct song *song, G_GNUC_UNUSED void *data)
 {
-	return addSongToPlaylist(song, NULL);
+	return addSongToPlaylist(&g_playlist, song, NULL);
 }
 
 struct add_data {
@@ -235,65 +207,32 @@ directoryPrintSongInfo(struct song *song, void *data)
 	return 0;
 }
 
-static int
-sumSongTime(struct song *song, void *data)
-{
-	unsigned long *sum_time = (unsigned long *)data;
-
-	if (song->tag && song->tag->time >= 0)
-		*sum_time += song->tag->time;
-
-	return 0;
-}
-
 int printInfoForAllIn(struct client *client, const char *name)
 {
 	return db_walk(name, directoryPrintSongInfo,
 			     printDirectoryInDirectory, client);
 }
 
-int countSongsIn(const char *name)
+static ListCommandItem *
+newListCommandItem(int tagType, const struct locate_item_list *criteria)
 {
-	int count = 0;
-	void *ptr = (void *)&count;
-
-	db_walk(name, NULL, countSongsInDirectory, ptr);
-
-	return count;
-}
-
-unsigned long sumSongTimesIn(const char *name)
-{
-	unsigned long dbPlayTime = 0;
-	void *ptr = (void *)&dbPlayTime;
-
-	db_walk(name, sumSongTime, NULL, ptr);
-
-	return dbPlayTime;
-}
-
-static ListCommandItem *newListCommandItem(int tagType, int numConditionals,
-					   LocateTagItem * conditionals)
-{
-	ListCommandItem *item = xmalloc(sizeof(ListCommandItem));
+	ListCommandItem *item = g_new(ListCommandItem, 1);
 
 	item->tagType = tagType;
-	item->numConditionals = numConditionals;
-	item->conditionals = conditionals;
+	item->criteria = criteria;
 
 	return item;
 }
 
 static void freeListCommandItem(ListCommandItem * item)
 {
-	free(item);
+	g_free(item);
 }
 
 static void
 visitTag(struct client *client, struct strset *set,
 	 struct song *song, enum tag_type tagType)
 {
-	int i;
 	struct tag *tag = song->tag;
 
 	if (tagType == LOCATE_TAG_FILE_TYPE) {
@@ -304,12 +243,13 @@ visitTag(struct client *client, struct strset *set,
 	if (!tag)
 		return;
 
-	for (i = 0; i < tag->numOfItems; i++) {
+	for (unsigned i = 0; i < tag->num_items; i++) {
 		if (tag->items[i]->type == tagType) {
 			strset_add(set, tag->items[i]->value);
 			return;
 		}
 	}
+
 	strset_add(set, "");
 }
 
@@ -325,20 +265,17 @@ listUniqueTagsInDirectory(struct song *song, void *_data)
 	struct list_tags_data *data = _data;
 	ListCommandItem *item = data->item;
 
-	if (tagItemsFoundAndMatches(song, item->numConditionals,
-	                            item->conditionals)) {
+	if (locate_song_match(song, item->criteria))
 		visitTag(data->client, data->set, song, item->tagType);
-	}
 
 	return 0;
 }
 
-int listAllUniqueTags(struct client *client, int type, int numConditionals,
-		      LocateTagItem * conditionals)
+int listAllUniqueTags(struct client *client, int type,
+		      const struct locate_item_list *criteria)
 {
 	int ret;
-	ListCommandItem *item = newListCommandItem(type, numConditionals,
-						   conditionals);
+	ListCommandItem *item = newListCommandItem(type, criteria);
 	struct list_tags_data data = {
 		.client = client,
 		.item = item,
@@ -357,7 +294,7 @@ int listAllUniqueTags(struct client *client, int type, int numConditionals,
 
 		while ((value = strset_next(data.set)) != NULL)
 			client_printf(client, "%s: %s\n",
-				      mpdTagItemKeys[type],
+				      tag_item_names[type],
 				      value);
 
 		strset_free(data.set);
@@ -367,37 +304,3 @@ int listAllUniqueTags(struct client *client, int type, int numConditionals,
 
 	return ret;
 }
-
-static int
-sumSavedFilenameMemoryInDirectory(struct directory *dir, void *data)
-{
-	int *sum = data;
-
-	if (isRootDirectory(dir->path))
-		return 0;
-
-	*sum += (strlen(directory_get_path(dir)) + 1
-		 - sizeof(struct directory *)) * dir->songs.nr;
-
-	return 0;
-}
-
-static int
-sumSavedFilenameMemoryInSong(struct song *song, void *data)
-{
-	int *sum = data;
-
-	*sum += strlen(song->url) + 1;
-
-	return 0;
-}
-
-void printSavedMemoryFromFilenames(void)
-{
-	int sum = 0;
-
-	db_walk(NULL, sumSavedFilenameMemoryInSong,
-		sumSavedFilenameMemoryInDirectory, (void *)&sum);
-
-	DEBUG("saved memory from filenames: %i\n", sum);
-}
