@@ -1,6 +1,6 @@
-/* the Music Player Daemon (MPD)
- * Copyright (C) 2008 Max Kellermann <max@duempel.org>
- * This project's homepage is: http://www.musicpd.org
+/*
+ * Copyright (C) 2003-2009 The Music Player Daemon Project
+ * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -11,9 +11,10 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef MPD_TAG_POOL_H
@@ -21,14 +22,18 @@
 
 #include "tag.h"
 
-#include <pthread.h>
+#include <glib.h>
 
-extern pthread_mutex_t tag_pool_lock;
+extern GMutex *tag_pool_lock;
 
 struct tag_item;
 
-struct tag_item *tag_pool_get_item(enum tag_type type,
-				   const char *value, int length);
+void tag_pool_init(void);
+
+void tag_pool_deinit(void);
+
+struct tag_item *
+tag_pool_get_item(enum tag_type type, const char *value, size_t length);
 
 struct tag_item *tag_pool_dup_item(struct tag_item *item);
 
