@@ -1,6 +1,6 @@
-/* the Music Player Daemon (MPD)
- * Copyright (C) 2003-2007 by Warren Dukes (warren.dukes@gmail.com)
- * This project's homepage is: http://www.musicpd.org
+/*
+ * Copyright (C) 2003-2009 The Music Player Daemon Project
+ * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -11,9 +11,10 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "tag_print.h"
@@ -27,22 +28,20 @@ void tag_print_types(struct client *client)
 	int i;
 
 	for (i = 0; i < TAG_NUM_OF_ITEM_TYPES; i++) {
-		if (ignoreTagItems[i] == 0)
+		if (!ignore_tag_items[i])
 			client_printf(client, "tagtype: %s\n",
-				      mpdTagItemKeys[i]);
+				      tag_item_names[i]);
 	}
 }
 
 void tag_print(struct client *client, const struct tag *tag)
 {
-	int i;
-
 	if (tag->time >= 0)
 		client_printf(client, SONG_TIME "%i\n", tag->time);
 
-	for (i = 0; i < tag->numOfItems; i++) {
+	for (unsigned i = 0; i < tag->num_items; i++) {
 		client_printf(client, "%s: %s\n",
-			      mpdTagItemKeys[tag->items[i]->type],
+			      tag_item_names[tag->items[i]->type],
 			      tag->items[i]->value);
 	}
 }
