@@ -1,6 +1,6 @@
-/* the Music Player Daemon (MPD)
- * Copyright (C) 2003-2007 by Warren Dukes (warren.dukes@gmail.com)
- * This project's homepage is: http://www.musicpd.org
+/*
+ * Copyright (C) 2003-2009 The Music Player Daemon Project
+ * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -11,9 +11,10 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "tag_save.h"
@@ -23,13 +24,11 @@
 
 void tag_save(FILE *file, const struct tag *tag)
 {
-	int i;
-
 	if (tag->time >= 0)
 		fprintf(file, SONG_TIME "%i\n", tag->time);
 
-	for (i = 0; i < tag->numOfItems; i++)
+	for (unsigned i = 0; i < tag->num_items; i++)
 		fprintf(file, "%s: %s\n",
-			mpdTagItemKeys[tag->items[i]->type],
+			tag_item_names[tag->items[i]->type],
 			tag->items[i]->value);
 }
